# Generated by Django 3.2.9 on 2022-06-13 09:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0003_auto_20220602_0950'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='active',
            field=models.BooleanField(default=False, verbose_name='Active'),
        ),
    ]
