# Generated by Django 3.2.16 on 2023-02-02 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0005_auto_20221216_1110'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text',
            field=models.CharField(default='Agree', max_length=128, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text_de',
            field=models.CharField(default='Agree', max_length=128, null=True, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_button_text_en',
            field=models.CharField(default='Agree', max_length=128, null=True, verbose_name='Confirm button text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox',
            field=models.BooleanField(default=False, verbose_name='Confirm checkbox'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, verbose_name='Confirm checkbox text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text_de',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, null=True, verbose_name='Confirm checkbox text'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='confirm_checkbox_text_en',
            field=models.CharField(default='I agree to the terms of this privacy policy', max_length=128, null=True, verbose_name='Confirm checkbox text'),
        ),
    ]
