# Generated by Django 3.2.9 on 2022-06-02 07:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0002_alter_privacypolicy_for_group'),
    ]

    operations = [
        migrations.AddField(
            model_name='privacypolicy',
            name='title',
            field=models.CharField(default='Privacy Policy', max_length=128, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='title_de',
            field=models.CharField(default='Privacy Policy', max_length=128, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='privacypolicy',
            name='title_en',
            field=models.CharField(default='Privacy Policy', max_length=128, null=True, verbose_name='Title'),
        ),
    ]
