# Generated by Django 3.2.9 on 2022-03-01 10:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('privacy_policy_tools', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privacypolicy',
            name='for_group',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.group', verbose_name='For group'),
        ),
    ]
