# Generated by Django 3.2.9 on 2022-02-25 10:46

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrivacyPolicy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(verbose_name='Text')),
                ('text_en', models.TextField(null=True, verbose_name='Text')),
                ('text_de', models.TextField(null=True, verbose_name='Text')),
                ('published_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Published at')),
                ('for_group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group', verbose_name='For group')),
            ],
            options={
                'verbose_name': 'Privacy Policy',
                'verbose_name_plural': 'Privacy Policies',
            },
        ),
        migrations.CreateModel(
            name='PrivacyPolicyConfirmation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('confirmed_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Confirmed at')),
                ('privacy_policy', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='privacy_policy_tools.privacypolicy', verbose_name='Privacy Policy')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Privacy Policy Confirmation',
                'verbose_name_plural': 'Privacy Policy Confirmations',
            },
        ),
    ]
