# Generated by Django 3.2.16 on 2022-12-16 10:10

import ckeditor.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('privacy_policy_tools', '0004_privacypolicy_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privacypolicy',
            name='text',
            field=ckeditor.fields.RichTextField(verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='privacypolicy',
            name='text_de',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='privacypolicy',
            name='text_en',
            field=ckeditor.fields.RichTextField(null=True, verbose_name='Text'),
        ),
    ]
